@@ -1,4 +1,5 @@
 import logging
+import os
 from iutest.core import appsettings
 from iutest.core import constants
 from iutest.qt import QtCore
@@ -25,9 +26,15 @@ class CodeLineVisitor(QtCore.QObject):
         QtCore.QObject.__init__(self, parent=parent)
         self._process = QtCore.QProcess(self)
 
+    @staticmethod
+    def _goToCmd(template, filePath, lineNumber):
+        cmd = template.replace(constants.CODE_FILE_VAR, filePath)
+        return cmd.replace(constants.CODE_LINE_VAR, str(lineNumber))
+
     def goTo(self, filePath, lineNumber=0):
-        cmd = self.config()
-        cmd = cmd.replace(constants.CODE_FILE_VAR, filePath)
-        cmd = cmd.replace(constants.CODE_LINE_VAR, str(lineNumber))
+        if os.path.isfile(filePath):
+            logger.warning("%s is not a valid file.", filePath)
+            
+        cmd = self._goToCmd(self.config(), filePath, lineNumber)
         logger.debug(cmd)
         self._process.start(cmd)
