@@ -1,15 +1,9 @@
 import logging
-import os
-import sys
-import collections
-import weakref
 
-from iutest import dependencies
 from iutest import dcc
 from iutest import _version
 from iutest.core import importutils
-from iutest.qt import QtCore, QtGui, QtWidgets, iconFromPath
-from iutest.core import pathutils
+from iutest.qt import QtCore, QtWidgets, iconFromPath, variantToPyValue
 from iutest.core import iconutils
 from iutest.core import appsettings
 from iutest.core import constants
@@ -17,7 +11,7 @@ from iutest.core import testmanager
 from iutest.core import uistream
 from iutest.ui import logbrowser
 from iutest.ui import rootpathedit
-from iutest.ui import utesttreeview
+from iutest.ui import unittesttree
 from iutest.ui import statuslabel
 from iutest.ui import uiutils
 from iutest.ui import configwindow
@@ -37,10 +31,7 @@ class IUTestWindow(QtWidgets.QWidget):
     _clearLogOnRunIcon = None
     _clearLogIcon = None
     _stopAtErrorIcon = None
-    _reimportAndRunIcon = None
-    _runPartialIcon = None
-    _runAllIcon = None
-    _runSelectedIcon = None
+    _configIcon = None
     _panelStateIconSet = None
 
     def __init__(self, startDirOrModule=None, topDir=None, parent=None):
@@ -56,6 +47,7 @@ class IUTestWindow(QtWidgets.QWidget):
 
         # Top layout ------------------------------
         self._dirLayout = uiutils.makeMinorHorizontalLayout()
+        self._testRunnerActions = []
         self._makeDirWidgets()
         self._mainLay.addLayout(self._dirLayout)
 
@@ -66,10 +58,10 @@ class IUTestWindow(QtWidgets.QWidget):
         self._leftWidget, leftLay = self._createSplitterContent()
 
         _topLayout = uiutils.makeMinorHorizontalLayout()
-        self._makeTopWidgets(_topLayout)
+        self._makeTreeTopWidgets(_topLayout)
         leftLay.addLayout(_topLayout)
 
-        self._view = utesttreeview.UTestTreeView(self)
+        self._view = unittesttree.UnitTestTreeView(self)
         self._view.runAllTest.connect(self._runAllTests)
         self._view.runTests.connect(self._runTests)
         self._view.runSetupOnly.connect(self._runTestSetupOnly)
@@ -91,13 +83,13 @@ class IUTestWindow(QtWidgets.QWidget):
         self._splitter.setStretchFactor(1, 1)
 
         # bottom -----------------------------------
+        self._statusLbl = statuslabel.StatusLabel(self)
+        self._mainLay.addWidget(self._statusLbl)
+
         _btmLayout = uiutils.makeMinorHorizontalLayout()
         self._makeRunButtons(_btmLayout)
         self._mainLay.addLayout(_btmLayout)
 
-        self._statusLbl = statuslabel.StatusLabel(self)
-        self._mainLay.addWidget(self._statusLbl)
-
         self.resize(QtCore.QSize(900, 500))
         self.setAttribute(QtCore.Qt.WA_DeleteOnClose, True)  # for reimport convenience.
         self.setTabOrder(self._rootDirLE, self._searchLE)
@@ -107,7 +99,6 @@ class IUTestWindow(QtWidgets.QWidget):
         self.setWindowFlags(QtCore.Qt.Window)
 
         self._updateWindowTitle()
-        self._setInitialTestMode()
         self._loadLastDirsFromSettings()
         self._restorePanelVisState()
 
@@ -115,6 +106,9 @@ class IUTestWindow(QtWidgets.QWidget):
 
         QtCore.QTimer.singleShot(0, self._initialLoad)
 
+    def getLogBrowserWidget(self):
+        return self._logWgt
+
     def resetUiTestManager(self):
         self._view.setTestManager(self._testManager)
         self._statusLbl.setTestManager(self._testManager)
@@ -132,17 +126,7 @@ class IUTestWindow(QtWidgets.QWidget):
         return wgt, splitterLay
 
     def _makeLogTopLayout(self, layout):
-        _console = QtWidgets.QLabel("Console")
-        self._clearLogOnRunBtn = uiutils.makeIconButton(self._clearLogOnRunIcon, self)
-        self._clearLogOnRunBtn.setToolTip(
-            "Clear the log browser automatically before every test run."
-        )
-        self._clearLogOnRunBtn.setCheckable(True)
-        autoClear = appsettings.get().simpleConfigBoolValue(
-            constants.CONFIG_KEY_AUTO_CLEAR_LOG_STATE
-        )
-        self._clearLogOnRunBtn.setChecked(autoClear)
-        self._clearLogOnRunBtn.toggled.connect(self._onAutoClearButtonToggled)
+        _console = QtWidgets.QLabel("Log Browser")
 
         self._clearLogBtn = uiutils.makeIconButton(self._clearLogIcon, self)
         self._clearLogBtn.setToolTip("Clear the log browser logging.")
@@ -150,7 +134,6 @@ class IUTestWindow(QtWidgets.QWidget):
 
         layout.addWidget(_console, 0)
         layout.addStretch(1)
-        layout.addWidget(self._clearLogOnRunBtn, 0)
         layout.addWidget(self._clearLogBtn, 0)
 
     @classmethod
@@ -164,83 +147,147 @@ class IUTestWindow(QtWidgets.QWidget):
             return
 
         panelStatePaths = iconutils.iconPathSet(
-            "panelMode.svg", constants.PANEL_VIS_STATE_ICON_SUFFIXES, includeInput=False
+            "panelMode.svg", constants.PANEL_VIS_STATE_ICON_SUFFIXES
         )
         cls._panelStateIconSet = [iconFromPath(p) for p in panelStatePaths]
 
-        cls._initSingleIcon("_iutestIcon", "iutest.svg")
-        cls._initSingleIcon("_reimportIcon", "reimport.svg")
-        cls._initSingleIcon("_reloadUiIcon", "reloadUI.svg")
-        cls._initSingleIcon("_clearIcon", "clear.svg")
-        cls._initSingleIcon("_moreIcon", "more.svg")
-        cls._initSingleIcon("_filterIcon", "stateFilter.svg")
-        cls._initSingleIcon("_autoFilterIcon", "autoFilter.svg")
-        cls._initSingleIcon("_resetIcon", "reset.svg")
-        cls._initSingleIcon("_clearLogIcon", "clearLog.svg")
-        cls._initSingleIcon("_clearLogOnRunIcon", "clearLogOnRun.svg")
-        cls._initSingleIcon("_stopAtErrorIcon", "stopAtError.svg")
-        cls._initSingleIcon("_reimportAndRunIcon", "reimportAndRerun.svg")
-        cls._initSingleIcon("_runPartialIcon", "run_partial.svg")
-        cls._initSingleIcon("_runAllIcon", "runAll.svg")
-        cls._initSingleIcon("_runSelectedIcon", "runSelected.svg")
+        iconutils.initSingleClassIcon(cls, "_iutestIcon", "iutest.svg")
+        iconutils.initSingleClassIcon(cls,"_reimportIcon", "reimport.svg")
+        iconutils.initSingleClassIcon(cls,"_reloadUiIcon", "reloadUI.svg")
+        iconutils.initSingleClassIcon(cls,"_configIcon", "config.svg")
+        iconutils.initSingleClassIcon(cls,"_clearIcon", "clear.svg")
+        iconutils.initSingleClassIcon(cls,"_moreIcon", "more.svg")
+        iconutils.initSingleClassIcon(cls,"_filterIcon", "stateFilter.svg")
+        iconutils.initSingleClassIcon(cls,"_autoFilterIcon", "autoFilter.svg")
+        iconutils.initSingleClassIcon(cls,"_resetIcon", "reset.svg")
+        iconutils.initSingleClassIcon(cls,"_clearLogIcon", "clearLog.svg")
+        iconutils.initSingleClassIcon(cls,"_clearLogOnRunIcon", "clearLogOnRun.svg")
+        iconutils.initSingleClassIcon(cls,"_stopAtErrorIcon", "stopAtError.svg")
 
-    def _regenerateMoreFeatureMenu(self):
-        self._moreMenu.clear()
+    def _addToggleConfigAction(self, lbl, icon, tooltip, configKey, slot):
+        # Cannot use self._configMenu.addAction() directly here since over-zealous garbage collection in some DCC apps:
+        act = QtWidgets.QAction(lbl, self)
+        act.setIcon(icon)
+        act.setCheckable(True)
+        act.setToolTip(tooltip)
+        act.toggled.connect(slot)
+        value = appsettings.get().simpleConfigBoolValue(configKey)
+        act.setChecked(value)
+        self._configMenu.addAction(act)
+        return (act, value)
 
-        act = self._moreMenu.addAction("Browse Test Root Dir ...")
+    def _regenerateBrowseMenu(self):
+        self._browseMenu.clear()
+
+        act = self._browseMenu.addAction("Pick Test Root Dir ...")
         act.triggered.connect(self._onBrowseTestsRootDir)
-        act = self._moreMenu.addAction("Browse Top Root Dir ...")
+        act = self._browseMenu.addAction("Pick Top Root Dir ...")
         act.triggered.connect(self._onBrowseTopDir)
-        self._moreMenu.addSeparator()
-        act = self._moreMenu.addAction("Save Current Path Settings ...")
+        self._browseMenu.addSeparator()
+        act = self._browseMenu.addAction("Save Current Path Settings ...")
         act.triggered.connect(self._onSaveCurrentDirSettings)
-        act = self._moreMenu.addAction("Delete Current Settings ...")
+        act = self._browseMenu.addAction("Delete Current Settings ...")
         act.triggered.connect(self._onDeleteCurrentDirSettings)
-        self._moreMenu.addSeparator()
+        self._browseMenu.addSeparator()
 
         # Read settings:
         config = appsettings.get().testDirSettings()
         for key, pair in config.items():
-            act = self._moreMenu.addAction(key)
+            act = self._browseMenu.addAction(key)
             act.triggered.connect(self._loadSavedDirPair)
             act.setToolTip("\n".join(pair))
-        self._moreMenu.addSeparator()
-        act = self._moreMenu.addAction("Config..")
+        self._browseMenu.addSeparator()
+
+    def _updateLabelOfTestRunnerAct(self, act, currentMode):
+        runnerMode = variantToPyValue(act.data())
+        runner = self._testManager.getRunnerByMode(runnerMode)
+        suffix = " [actived]" if runnerMode == currentMode else ""
+        lbl = runner.name() + suffix
+        act.setText(lbl)
+
+    def _updateConfigButton(self, runner):
+        self._runnerConfigBtn.setIcon(runner.icon())
+        self._runnerConfigBtn.setToolTip("Test Runner: {}, click for more settings.".format(runner.name()))
+
+    def _makeRunnerConfigButton(self):
+        currentRunner = self._setInitialTestMode()
+        currentRunnerMode = currentRunner.mode()
+        self._runnerConfigBtn, self._configMenu = self._makeMenuToolButton()
+        self._updateConfigButton(currentRunner)
+        
+        for runner in self._testManager.iterAllRunners():
+            icon = runner.icon()
+            toolTip = "Run tests using {}.".format(runner.name())
+            runnerMode = runner.mode()
+            act = QtWidgets.QAction(runner.name(), self)
+            act.setIcon(icon)
+            act.setEnabled(runner.isValid())
+            act.setToolTip(toolTip)
+            act.setData(runnerMode)
+            act.triggered.connect(self._onTestRunnerSwitched)
+            self._updateLabelOfTestRunnerAct(act, currentRunnerMode)
+            self._testRunnerActions.append(act)
+            self._configMenu.addAction(act)
+
+        self._configMenu.addSeparator()
+
+        # Stop on error act:
+        self._stopOnErrorAct, stopOnError = self._addToggleConfigAction(
+            "Stop On Error",
+            self._stopAtErrorIcon,
+            "Stop the tests running once it encounters a test error/failure.",
+            configKey=constants.CONFIG_KEY_STOP_ON_ERROR,
+            slot=self._onStopOnErrorActionToggled
+        )
+        self._testManager.setStopOnError(stopOnError)
+
+        # auto filer on run act:
+        self._autoFilterAct, stopOnError = self._addToggleConfigAction(
+            "Only Show Tests that Run",
+            self._autoFilterIcon,
+            "Apply a ':ran' filter automatically after every test run so that only the run tests shown in the view.",
+            configKey=constants.CONFIG_KEY_AUTO_FILTERING_STATE,
+            slot=self._onAutoFilterActionToggled
+        )
+
+        # auto clear log on run act:
+        self._clearLogOnRunAct, stopOnError = self._addToggleConfigAction(
+            "Clear LogBrowser On Run",
+            self._clearLogOnRunIcon,
+            "Clear the log browser automatically before every test run.",
+            configKey=constants.CONFIG_KEY_AUTO_CLEAR_LOG_STATE,
+            slot=self._onAutoClearLogActionToggled
+        )
+
+        self._configMenu.addSeparator()
+        act = self._configMenu.addAction("Preference..")
+        act.setIcon(self._configIcon)
         act.triggered.connect(self._showConfigWindow)
 
     def _showConfigWindow(self):
         configwindow.ConfigWindow.show(self)
 
-    def _makeMenuToolButton(self, icon, toolTip):
+    def _makeMenuToolButton(self, icon=None, toolTip=""):
         btn = QtWidgets.QToolButton(self)
-        btn.setIcon(icon)
+        if icon:
+            btn.setIcon(icon)
         btn.setToolTip(toolTip)
+        btn.setContentsMargins(0,0,0,0)
+        btn.setIconSize(QtCore.QSize(20,20))
         btn.setPopupMode(btn.InstantPopup)
         menu = QtWidgets.QMenu(btn)
         btn.setMenu(menu)
         return (btn, menu)
 
     def _setInitialTestMode(self):
-        initRunnerMode = self._testManager.getInitialRunnerMode()
+        initRunnerMode = appsettings.get().simpleConfigIntValue(
+            constants.CONFIG_KEY_LAST_RUNNER_MODE, -1
+        )
+        if initRunnerMode < 0:
+            initRunnerMode = self._testManager.getFeasibleRunnerMode()
+            
         self._testManager.setRunnerMode(initRunnerMode)
-        if initRunnerMode in self._testModeButtons:
-            self._testModeButtons[initRunnerMode].setChecked(True)
-
-    def _makeTestModeWidget(self, layout):
-        self._testModeButtons = {}
-        for runner in self._testManager.iterAllRunners(excludeDummy=True):
-            icon = runner.icon()
-            toolTip = "Run {} tests.".format(runner.name())
-            runnerMode = runner.mode()
-            btn = uiutils.makeIconButton(icon, self)
-            btn.setEnabled(runner.isValid())
-            btn.setCheckable(True)
-            btn.setAutoExclusive(True)
-            btn.setToolTip(toolTip)
-            btn.setWindowTitle(str(runnerMode))
-            btn.clicked.connect(self._onTestModeClicked)
-            layout.addWidget(btn)
-            self._testModeButtons[runnerMode] = btn
+        return self._testManager.getRunner()
 
     def _makeDirWidgets(self):
         lbl = QtWidgets.QLabel("Test Root")
@@ -250,29 +297,29 @@ class IUTestWindow(QtWidgets.QWidget):
         self._rootDirLE = rootpathedit.RootPathEdit(self)
         self._rootDirLE.rootPathChanged.connect(self._switchToTestRootPath)
 
-        self._browseBtn, self._moreMenu = self._makeMenuToolButton(
+        self._browseBtn, self._browseMenu = self._makeMenuToolButton(
             self._moreIcon, "Click to access more features."
         )
-        self._regenerateMoreFeatureMenu()
+        self._regenerateBrowseMenu()
 
         self._panelVisBtn = uiutils.makeIconButton(self._panelStateIconSet[-1], self)
         self._panelVisBtn.setToolTip(
             "Switch the test tree view and the log browser visibility."
         )
         self._panelVisBtn.clicked.connect(self._onPanelVisButtonClicked)
+        self._makeRunnerConfigButton()
 
         self._dirLayout.addWidget(lbl)
         self._dirLayout.addWidget(self._rootDirLE)
         self._dirLayout.addWidget(self._browseBtn)
         self._dirLayout.addWidget(self._panelVisBtn)
-        uiutils.addSeparatorToLayout(self._dirLayout, QtCore.Qt.Vertical)
-        self._makeTestModeWidget(self._dirLayout)
+        self._dirLayout.addWidget(self._runnerConfigBtn)
 
         self._updateDirUI()
 
-    def _makeTopWidgets(self, layout):
+    def _makeTreeTopWidgets(self, layout):
         reimportBtn = uiutils.makeIconButton(self._reimportIcon, self)
-        reimportBtn.setEnabled(dependencies.ReimportWrapper.get().isValid())
+        reimportBtn.setVisible(importutils.isReimportFeatureAvailable(silentCheck=True))
         reimportBtn.setToolTip("Reimport all changed python module.")
         reimportBtn.clicked.connect(self._reimportAllChangedModules)
         layout.addWidget(reimportBtn)
@@ -306,58 +353,39 @@ class IUTestWindow(QtWidgets.QWidget):
             act.triggered.connect(self._addStateFilter)
         layout.addWidget(self._filterBtn)
 
-        self._autoFilterBtn = uiutils.makeIconButton(self._autoFilterIcon, self)
-        self._autoFilterBtn.setToolTip(
-            "Apply a ':ran' filter automatically after every test run so that only the run tests shown in the view."
-        )
-        self._autoFilterBtn.setCheckable(True)
-        autoFilter = appsettings.get().simpleConfigBoolValue(
-            constants.CONFIG_KEY_AUTO_FILTERING_STATE
-        )
-        self._autoFilterBtn.setChecked(autoFilter)
-        self._autoFilterBtn.toggled.connect(self._onAutoFilterButtonToggled)
-        layout.addWidget(self._autoFilterBtn)
-
-    def _onAutoFilterButtonToggled(self, state):
+    def _onAutoFilterActionToggled(self, state):
         appsettings.get().saveSimpleConfig(
             constants.CONFIG_KEY_AUTO_FILTERING_STATE, state
         )
 
-    def _onAutoClearButtonToggled(self, state):
+    def _onAutoClearLogActionToggled(self, state):
         appsettings.get().saveSimpleConfig(
             constants.CONFIG_KEY_AUTO_CLEAR_LOG_STATE, state
         )
 
-    def _onTestModeClicked(self):
-        btn = self.sender()
-        if not btn:
+    def _onTestRunnerSwitched(self):
+        act = self.sender()
+        if not act:
             return
 
-        runnerMode = int(btn.windowTitle())
+        runnerMode = variantToPyValue(act.data())
         self._testManager.setRunnerMode(runnerMode)
+        runner = self._testManager.getRunner()
+        self._updateConfigButton(runner)
+        logger.info("Switch to %s for test running.", runner.name())
+        
         self._onReloadUiButtonClicked()
         appsettings.get().saveSimpleConfig(
             constants.CONFIG_KEY_LAST_RUNNER_MODE, runnerMode
         )
+        for act in self._testRunnerActions:
+            self._updateLabelOfTestRunnerAct(act, runnerMode)
 
-    def _onStopOnErrorButtonToggled(self, stop):
+    def _onStopOnErrorActionToggled(self, stop):
         self._testManager.setStopOnError(stop)
         appsettings.get().saveSimpleConfig(constants.CONFIG_KEY_STOP_ON_ERROR, stop)
 
     def _makeRunButtons(self, _btmLayout):
-        self._stopAtErrorBtn = uiutils.makeIconButton(self._stopAtErrorIcon, self)
-        self._stopAtErrorBtn.toggled.connect(self._onStopOnErrorButtonToggled)
-        self._stopAtErrorBtn.setToolTip(
-            "Stop the tests running once it encounters a test error/failure."
-        )
-        self._stopAtErrorBtn.setCheckable(True)
-        stopOnError = appsettings.get().simpleConfigBoolValue(
-            constants.CONFIG_KEY_STOP_ON_ERROR
-        )
-        self._stopAtErrorBtn.setChecked(stopOnError)
-        self._testManager.setStopOnError(stopOnError)
-        _btmLayout.addWidget(self._stopAtErrorBtn, 0)
-
         self._resetAllBtn = uiutils.makeIconButton(self._resetIcon, self)
         self._resetAllBtn.setToolTip(
             "Reset the test item states, icons and stats and collapse the tree view items in a certain level."
@@ -368,14 +396,14 @@ class IUTestWindow(QtWidgets.QWidget):
         self._runSelectedBtn = QtWidgets.QPushButton("Run &Selected", self)
         self._runSelectedBtn.setToolTip("Run the selected tests in the view.")
         self._runSelectedBtn.clicked.connect(self._runViewSelectedTests)
-        self._runSelectedBtn.setIcon(self._runSelectedIcon)
+        self._runSelectedBtn.setIcon(self._view._runSelectedIcon)
         _btmLayout.addWidget(self._runSelectedBtn, 1)
 
         self._runAllBtn = QtWidgets.QPushButton("Run &All", self)
         self._runAllBtn.setToolTip(
             "Run all the tests, including those filtered from the view."
         )
-        self._runAllBtn.setIcon(self._runAllIcon)
+        self._runAllBtn.setIcon(self._view._runAllIcon)
         self._runAllBtn.clicked.connect(self._runAllTests)
         _btmLayout.addWidget(self._runAllBtn, 1)
 
@@ -384,7 +412,7 @@ class IUTestWindow(QtWidgets.QWidget):
             "Reimport all changed python modules and rerun the last tests."
         )
         self._reimportAndRerunBtn.clicked.connect(self._reimportPyAndRerun)
-        self._reimportAndRerunBtn.setIcon(self._reimportAndRunIcon)
+        self._reimportAndRerunBtn.setIcon(self._view._reimportAndRunIcon)
         _btmLayout.addWidget(self._reimportAndRerunBtn, 1)
 
         _runMoreBtn = self._makeRunMoreButton()
@@ -392,13 +420,17 @@ class IUTestWindow(QtWidgets.QWidget):
 
     def _makeRunMoreButton(self):
         _runMoreBtn = QtWidgets.QToolButton(self)
-        _runMoreBtn.setIcon(self._runPartialIcon)
+        _runMoreBtn.setIcon(self._view._runPartialIcon)
         _runMoreBtn.setAutoRaise(True)
         _runMoreBtn.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
         _runMoreBtn.setPopupMode(_runMoreBtn.InstantPopup)
+
         self._runSetupAct = QtWidgets.QAction("Run setUp( ) Only", self)
+        self._runSetupAct.setIcon(self._view._runPartialIcon)
         self._runSetupAct.triggered.connect(self._runTestSetupOnly)
+
         self._runNoTearDown = QtWidgets.QAction("Run without tearDown( )", self)
+        self._runNoTearDown.setIcon(self._view._runPartialIcon)
         self._runNoTearDown.triggered.connect(self._runTestWithoutTearDown)
 
         menu = QtWidgets.QMenu(_runMoreBtn)
@@ -415,8 +447,8 @@ class IUTestWindow(QtWidgets.QWidget):
         self._applyCurrentFilter(removeStateFilters=True, keepUiStates=True)
 
     def _addStateFilter(self):
-        stateKeyword = self.sender().text()
-        search = self._searchLE.text().strip()
+        stateKeyword = str(self.sender().text())
+        search = str(self._searchLE.text()).strip()
         if not search:
             self._searchLE.setText(stateKeyword)
             return
@@ -440,7 +472,7 @@ class IUTestWindow(QtWidgets.QWidget):
         self._testManager.setTopDir(_topDir)
         self._testManager.setStartDirOrModule(_startDirOrModule)
 
-        configName = act.text()
+        configName = str(act.text())
         self._saveLastTestDir(_startDirOrModule, _topDir)
         self._updateWindowTitle(configName)
         self._updateDirUI()
@@ -453,7 +485,7 @@ class IUTestWindow(QtWidgets.QWidget):
         self._updateDirUI()
         self._searchLE.clear()
         self.reload(keepUiStates=False)
-        if not self._testManager.lastListerError():
+        if not self._testManager.hasLastListerError():
             self._saveLastTestDir(startDir, topDir)
 
     def _setPanelVisState(self, state, saveSettings=True):
@@ -562,7 +594,7 @@ class IUTestWindow(QtWidgets.QWidget):
         self._updateWindowTitle(name[0])
 
     def _deferredRegenerateMenu(self):
-        QtCore.QTimer.singleShot(0, self._regenerateMoreFeatureMenu)
+        QtCore.QTimer.singleShot(0, self._regenerateBrowseMenu)
 
     def _onDeleteCurrentDirSettings(self):
         config = appsettings.get().testDirSettings()
@@ -612,7 +644,7 @@ class IUTestWindow(QtWidgets.QWidget):
         self._runNoTearDown.setEnabled(hasSelForPartialRun)
 
     def _runViewSelectedTests(self):
-        self._runTests(self._view.selectedTestIds())
+        self._runTests(self._view.selectedTestIds(decomposePackageIfNecessary=True))
 
     def _updateReimportRerunButtonEnabled(self):
         self._reimportAndRerunBtn.setEnabled(bool(self._testManager.lastRunTestIds()))
@@ -633,9 +665,9 @@ class IUTestWindow(QtWidgets.QWidget):
         self._runPartialTest(constants.RUN_TEST_NO_TEAR_DOWN)
 
     def _runPartialTest(self, partialMode):
-        testId = self._view.firstSelectedTestOrTestCase()
+        testId = self._view.firstSelectedTestCaseId()
         if not testId:
-            logger.error("You need to select testCase or test item.")
+            logger.error("You need to select test suite or test case.")
             return
         self._testManager.runSingleTestPartially(testId, partialMode)
         self._updateReimportRerunButtonEnabled()
@@ -656,7 +688,7 @@ class IUTestWindow(QtWidgets.QWidget):
         self._statusLbl.reportTestCount(self._view.testCount())
 
     def _applyCurrentFilter(self, removeStateFilters=True, keepUiStates=True):
-        searchText = self._searchLE.text()
+        searchText = str(self._searchLE.text())
         if removeStateFilters:
             keywords = searchText.split(" ")
             filterFunc = lambda x: not x.startswith(":")
@@ -673,26 +705,34 @@ class IUTestWindow(QtWidgets.QWidget):
         self._viewSelectionChanged()
         self._updateReimportRerunButtonEnabled()
 
+    def _hookUiToStream(self):
+        uistream.UiStream.setUi(self)
+
     def _beforeTestCollection(self):
-        self._logWgt.onTestStart()
+        self._hookUiToStream()
         self._statusLbl.startCollectingTests()
 
     def _beforeRunningTests(self, tests):
-        self._logWgt.onTestStart()
+        self._hookUiToStream()
         self._view.resetTestItemsById(tests)
 
     def _applyFilterText(self, txt):
-        self._applyFilterTextWithState(txt, keepUiStates=False)
+        self._applyFilterTextWithState(str(txt), keepUiStates=False)
 
     def _applyFilterTextWithState(self, txt, keepUiStates=True):
         lowerTxt = txt.strip().lower()
         keywords = lowerTxt.split(" ")
         self._clearFilterBtn.setEnabled(bool(keywords))
         self._view.setFilterKeywords(keywords, ensureFirstMatchVisible=not keepUiStates)
+    
+    def closeEvent(self, event):
+        uistream.UiStream.unsetUi(self)
+        QtWidgets.QWidget.closeEvent(self, event)
 
     # These below are to be called by hooks -------------------------------------------------
-    def onSingleTestStartToRun(self, testId, startTime):
-        self._view.onSingleTestStartToRun(testId, startTime)
+    def onSingleTestStart(self, testId, startTime):
+        self._hookUiToStream()
+        self._view.onSingleTestStart(testId, startTime)
 
     def onSingleTestStop(self, testId, endTime):
         self._view.onSingleTestStop(testId, endTime)
@@ -703,13 +743,13 @@ class IUTestWindow(QtWidgets.QWidget):
 
     def onTestRunningSessionStart(self):
         self._statusLbl.setText("Running tests...")
-        if self._clearLogOnRunBtn.isChecked():
+        if self._clearLogOnRunAct.isChecked():
             self._logWgt.clear()
         self._logWgt.logSeparator()
 
     def onAllTestsFinished(self):
         self._view.onAllTestsFinished()
-        if self._autoFilterBtn.isChecked():
+        if self._autoFilterAct.isChecked():
             self._searchLE.setText(constants.KEYWORD_TEST_STATE_RUN)
         self._statusLbl.updateReport()
 
